/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * The applicable license agreement can be found at this pack's installation directory in the file
 * license/IFX_SW_Licence_MOTIX_LITIX.txt
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** BG           Blandine Guillot                                              **
** MS           Mohamed  Sassi                                                **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2020-04-15, BG:   Initial  version of revision history             **
** V1.0.1: 2020-07-21, BG:   EP-439:  Formatted .h/.c files                   **
** V1.0.2: 2020-08-04, BG:   EP-431:  Fixed ARMCC v6 compiler warnings        **
** V1.0.3: 2022-10-20, MS:   EP-1327: Changed Poti_handler conditional        **
**                           statements                                       **
** V1.1.0: 2024-11-06, JO:   EP-1535: Fixed compiler warnings (ARMCC V6.22)   **
** V1.1.1: 2025-01-02, JO:   EP-1493: Updated license                         **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** ADC1: Display Poti position with LEDs                                      **
********************************************************************************
** Read Poti voltage with ADC1-Ch4.                                           **
** The voltage measured on Ch4 is divided in 8 intervals and displayed        **
** accordingly on the 8 LEDs.                                                 **
*******************************************************************************/

#include "tle_device.h"
#include "eval_board.h"

void Poti_Handler(void);


int main(void)
{
  /* Initialization of hardware modules based on Config Wizard configuration */
  TLE_Init();
  /* Start Timer13 */
  CCU6_StartTmr_T13();

  for (;;)
  {
    (void)WDT1_Service();
  }
}


void Poti_Handler(void)
{
#define Interval_mV 555u
  uint16 mV;
  bool value_valid;
  value_valid = ADC1_GetChResult_mV(&mV, ADC1_CH4);

  if (value_valid == true)
  {
    switch (mV / Interval_mV)
    {	
      case 0:
        PORT_ChangePin(LED1, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED2, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED3, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED4, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED5, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED6, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED7, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED8, PORT_ACTION_CLEAR);
        break;
      case 1:
        PORT_ChangePin(LED1, PORT_ACTION_SET);
        PORT_ChangePin(LED2, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED3, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED4, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED5, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED6, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED7, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED8, PORT_ACTION_CLEAR);
        break;
      case 2:
        PORT_ChangePin(LED1, PORT_ACTION_SET);
        PORT_ChangePin(LED2, PORT_ACTION_SET);
        PORT_ChangePin(LED3, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED4, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED5, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED6, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED7, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED8, PORT_ACTION_CLEAR);
        break;
      case 3:
        PORT_ChangePin(LED1, PORT_ACTION_SET);
        PORT_ChangePin(LED2, PORT_ACTION_SET);
        PORT_ChangePin(LED3, PORT_ACTION_SET);
        PORT_ChangePin(LED4, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED5, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED6, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED7, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED8, PORT_ACTION_CLEAR);
        break;
      case 4:
        PORT_ChangePin(LED1, PORT_ACTION_SET);
        PORT_ChangePin(LED2, PORT_ACTION_SET);
        PORT_ChangePin(LED3, PORT_ACTION_SET);
        PORT_ChangePin(LED4, PORT_ACTION_SET);
        PORT_ChangePin(LED5, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED6, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED7, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED8, PORT_ACTION_CLEAR);
        break;
      case 5:
        PORT_ChangePin(LED1, PORT_ACTION_SET);
        PORT_ChangePin(LED2, PORT_ACTION_SET);
        PORT_ChangePin(LED3, PORT_ACTION_SET);
        PORT_ChangePin(LED4, PORT_ACTION_SET);
        PORT_ChangePin(LED5, PORT_ACTION_SET);
        PORT_ChangePin(LED6, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED7, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED8, PORT_ACTION_CLEAR);
        break;
      case 6:
        PORT_ChangePin(LED1, PORT_ACTION_SET);
        PORT_ChangePin(LED2, PORT_ACTION_SET);
        PORT_ChangePin(LED3, PORT_ACTION_SET);
        PORT_ChangePin(LED4, PORT_ACTION_SET);
        PORT_ChangePin(LED5, PORT_ACTION_SET);
        PORT_ChangePin(LED6, PORT_ACTION_SET);
        PORT_ChangePin(LED7, PORT_ACTION_CLEAR);
        PORT_ChangePin(LED8, PORT_ACTION_CLEAR);
        break;
      case 7:
        PORT_ChangePin(LED1, PORT_ACTION_SET);
        PORT_ChangePin(LED2, PORT_ACTION_SET);
        PORT_ChangePin(LED3, PORT_ACTION_SET);
        PORT_ChangePin(LED4, PORT_ACTION_SET);
        PORT_ChangePin(LED5, PORT_ACTION_SET);
        PORT_ChangePin(LED6, PORT_ACTION_SET);
        PORT_ChangePin(LED7, PORT_ACTION_SET);
        PORT_ChangePin(LED8, PORT_ACTION_CLEAR);
        break;
      default:
        PORT_ChangePin(LED1, PORT_ACTION_SET);
        PORT_ChangePin(LED2, PORT_ACTION_SET);
        PORT_ChangePin(LED3, PORT_ACTION_SET);
        PORT_ChangePin(LED4, PORT_ACTION_SET);
        PORT_ChangePin(LED5, PORT_ACTION_SET);
        PORT_ChangePin(LED6, PORT_ACTION_SET);
        PORT_ChangePin(LED7, PORT_ACTION_SET);
        PORT_ChangePin(LED8, PORT_ACTION_SET);
        break;
  	}	
  }
}
