/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * The applicable license agreement can be found at this pack's installation directory in the file
 * license/IFX_SW_Licence_MOTIX_LITIX.txt
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** ISLE         ISLE Ilmenau                                                  **
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2016-07-20, ISLE: Initial version of revision history              **
** V1.0.1: 2020-04-15, BG:   Updated revision history                         **
** V1.0.2: 2020-07-21, BG:   EP-439: Formatted .h/.c files                    **
** V1.1.0: 2024-11-06, JO:   EP-1535: Fixed compiler warnings (ARMCC V6.22)   **
** V1.1.1: 2025-01-02, JO:   EP-1493: Updated license                         **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** BLDC BEMF: Motor Drive with sensorless block commutation (BEMF)            **
********************************************************************************
** This example is configured to work with the Trinamic QBL 4208-61-04-013    **
** motor.                                                                     **
** Press the MON button to have the motor run with 2000 rpm.                  **
** It is also possible to use negative speed to turn the motor in the         **
** opposite direction.                                                        **
*******************************************************************************/

#include <tle_device.h>
#include "Emo_BEMF.h"

static void Main_lStartMotor(void);
static void Main_lStopMotor(void);
void Main_HandleSysTick(void);

static uint8 bMotorRun;


int main(void)
{
  /* Initialization of hardware modules based on Config Wizard configuration */
  TLE_Init();
  Emo_Init();
  Emo_setspeedreferenz(2000);

  for (;;)
  {
    /* Service watchdog */
    (void)WDT1_Service();

    /* Wait for MON button to be pressed */
    if (MON_Debounce(0u) == 0u)
    {
      if (bMotorRun == 0u)
      {
        /* Start motor to run up to the desired speed */
        Main_lStartMotor();
        bMotorRun = 1u;
      }
      else
      {
        /* Stop motor */
        Main_lStopMotor();
        /* Reinitialise motor control parameters */
        Emo_Init();
        bMotorRun = 0u;
      }

      /* Wait until MON button is released */
      while (MON_Debounce(1u) == 0u) {}
    }
  }
}


void Main_HandleSysTick(void)
{
}


static void Main_lStartMotor(void)
{
  uint32 Error;
  Error = EMO_ERROR_NONE;

  if (Error == EMO_ERROR_NONE)
  {
    Error = Emo_StartMotor();
  }

  if (Error == EMO_ERROR_NONE)
  {
  }
  else /* Error */
  {
  }
}


static void Main_lStopMotor(void)
{
  uint32 Error;
  Error = Emo_StopMotor();

  if (Error != EMO_ERROR_NONE)
  {
  }
}
