/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * The applicable license agreement can be found at this pack's installation directory in the file
 * license/IFX_SW_Licence_MOTIX_LITIX.txt
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** BG           Blandine Guillot                                              **
** CK           Chander Kumar                                                 **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2020-04-15, BG:   Initial version of revision history              **
** V1.0.1: 2020-07-21, BG:   EP-439: Formatted .h/.c files                    **
** V1.0.2: 2022-05-25, CK:   EP-1155: Added selection of motor in CW and      **
**                           modified hall patterns in EmoCcu_Cfg.c           **
** V1.1.0: 2024-11-06, JO:   EP-1535: Set C version to C99                    **
**                           Set compiler warning level to 'all warnings'     **
**                           Fixed compiler warnings (ARMCC V6.22)            **
** V1.1.1: 2025-01-02, JO:   EP-1493: Updated license                         **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** BLDC: Motor Drive with block commutation and Hall sensor                   **
********************************************************************************
** Use the Poti to start/stop and speed up the motor.                         **
** Motor connection, QBL4208:                                                 **
** Phase 1             : yellow                                               **
** Phase 2             : red                                                  **
** Phase 3             : black                                                **
** Hall A - P0.3       : blue  (Motor Hall A)                                 **
** Hall B - P0.4       : green (Motor Hall B)                                 **
** Hall C - P1.2       : white (Motor Hall C)                                 **
** Hall Supply - VDDEXT: red                                                  **
** Hall Gnd - GND      : black                                                **
**                                                                            **
** Motor connection, DB42S03 Nanotec:                                         **
** Phase 1             : yellow                                               **
** Phase 2             : red                                                  **
** Phase 3             : black                                                **
** Hall A - P0.3       : blue  (Motor Hall A)                                 **
** Hall B - P0.4       : white (Motor Hall B)                                 **
** Hall C - P1.2       : green (Motor Hall C)                                 **
** Hall Supply - VDDEXT: red                                                  **
** Hall Gnd - GND      : black                                                **
*******************************************************************************/

#include "tle_device.h"
#include "Emo.h"

static void Main_lStartMotor(void);
static void Main_lStopMotor(void);
void Poti_Handler(void);
void Main_HandleSysTick(void);


int main(void)
{
  /* Initialization of hardware modules based on Config Wizard configuration */
  TLE_Init();
  /* Initialize E-Motor application */
  Emo_Init();
  /* Start poti readout after Emo has been initialized */
  ADC1_Ch4_Int_En();

  for (;;)
  {
    /* Service watchdog */
    (void)WDT1_Service();
  }
}


void Main_HandleSysTick(void)
{
  /* Callback function executed every ms for speed control */
  Emo_CtrlSpeed();
}


static void Main_lStartMotor(void)
{
  uint32 Error;
  Error = EMO_ERROR_NONE;

  if (Error == EMO_ERROR_NONE)
  {
    /* Start motor with desired positive or negative speed in [rpm] */
    Error = Emo_StartMotor();
  }

  if (Error == EMO_ERROR_NONE)
  {
  }
  else /* Error */
  {
  }
}


static void Main_lStopMotor(void)
{
  uint32 Error;
  Error = Emo_StopMotor();

  if (Error != EMO_ERROR_NONE)
  {
  }
}


void Poti_Handler(void)
{
  uint16 mV;

  /* Read the value at Ch4 (Poti) in mV - values between 0 and 5000 are possible */
  if (ADC1_GetChResult_mV(&mV, ADC1_CH4) == true)
  {
    Emo_SetRefSpeed(mV / 2);

    if (mV > 100)
    {
      Main_lStartMotor();
      PORT_P01_Output_High_Set();
    }
    else
    {
      Main_lStopMotor();
      PORT_P01_Output_Low_Set();
    }
  }
}
