/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * The applicable license agreement can be found at this pack's installation directory in the file
 * license/IFX_SW_Licence_MOTIX_LITIX.txt
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** BG           Blandine Guillot                                              **
** CK           Chander Kumar                                                 **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2020-04-15, BG:   Initial version of revision history              **
** V1.0.1: 2022-07-18, CK:   EP-1147: Modified hall patterns for QBL and      **
**                           Nanotec motors                                   **
** V1.0.2: 2025-01-02, JO:   EP-1493: Updated license                         **
*******************************************************************************/

#include "EmoCcu.h"

/*******************************************************************************
**                          Private Macro Definitions                         **
*******************************************************************************/

#define Ccu6_SetPtns(CURHS, EXPHS, MCMPS) \
  ( (((uint32)(MCMPS)) << 0u) | \
  (((uint32)(EXPHS)) << 8u) | \
  (((uint32)(CURHS)) << 11U ) )

/*******************************************************************************
**                 Global Constant Definitions to be changed                  **
*******************************************************************************/
const TEmoCcu_Cfg EmoCcu_Cfg =
{
  /* HallOutPtns[16] - Hall and output patterns
   * Value = f(current Hall pattern, expected Hall pattern, output pattern)
   */
#if MOTOR_TYPE == 0  /* QBL4208-41-03-006 motor */
{
  (uint16)Ccu6_SetPtns(0, 0, 0x00), /* Hall pattern=0, forward direction (error) */
  (uint16)Ccu6_SetPtns(1, 5, 0x13), /* Hall pattern=1, forward direction */
  (uint16)Ccu6_SetPtns(2, 3, 0x0D), /* Hall pattern=2, forward direction */
  (uint16)Ccu6_SetPtns(3, 1, 0x1C), /* Hall pattern=3, forward direction */
  (uint16)Ccu6_SetPtns(4, 6, 0x34), /* Hall pattern=4, forward direction */
  (uint16)Ccu6_SetPtns(5, 4, 0x07), /* Hall pattern=5, forward direction */
  (uint16)Ccu6_SetPtns(6, 2, 0x31), /* Hall pattern=6, forward direction */
  (uint16)Ccu6_SetPtns(0, 0, 0x00), /* Hall pattern=7, forward direction (error) */
  (uint16)Ccu6_SetPtns(0, 0, 0x00), /* Hall pattern=0, reverse direction (error) */
  (uint16)Ccu6_SetPtns(1, 3, 0x31), /* Hall pattern=1, reverse direction */
  (uint16)Ccu6_SetPtns(2, 6, 0x07), /* Hall pattern=2, reverse direction */
  (uint16)Ccu6_SetPtns(3, 2, 0x34), /* Hall pattern=3, reverse direction */
  (uint16)Ccu6_SetPtns(4, 5, 0x1C), /* Hall pattern=4, reverse direction */
  (uint16)Ccu6_SetPtns(5, 1, 0x0D), /* Hall pattern=5, reverse direction */
  (uint16)Ccu6_SetPtns(6, 4, 0x13), /* Hall pattern=6, reverse direction */
  (uint16)Ccu6_SetPtns(0, 0, 0x00)  /* Hall pattern=7, reverse direction (error) */
},

#elif MOTOR_TYPE == 1  /* QBL4208-61-04-013 motor */
{
  (uint16)Ccu6_SetPtns(0, 0, 0x00), /* Hall pattern=0, forward direction (error) */
  (uint16)Ccu6_SetPtns(1, 5, 0x31), /* Hall pattern=1, forward direction */
  (uint16)Ccu6_SetPtns(2, 3, 0x07), /* Hall pattern=2, forward direction */
  (uint16)Ccu6_SetPtns(3, 1, 0x34), /* Hall pattern=3, forward direction */
  (uint16)Ccu6_SetPtns(4, 6, 0x1C), /* Hall pattern=4, forward direction */
  (uint16)Ccu6_SetPtns(5, 4, 0x0D), /* Hall pattern=5, forward direction */
  (uint16)Ccu6_SetPtns(6, 2, 0x13), /* Hall pattern=6, forward direction */
  (uint16)Ccu6_SetPtns(0, 0, 0x00), /* Hall pattern=7, forward direction (error) */
  (uint16)Ccu6_SetPtns(0, 0, 0x00), /* Hall pattern=0, reverse direction (error) */
  (uint16)Ccu6_SetPtns(1, 3, 0x13), /* Hall pattern=1, reverse direction */
  (uint16)Ccu6_SetPtns(2, 6, 0x0D), /* Hall pattern=2, reverse direction */
  (uint16)Ccu6_SetPtns(3, 2, 0x1C), /* Hall pattern=3, reverse direction */
  (uint16)Ccu6_SetPtns(4, 5, 0x34), /* Hall pattern=4, reverse direction */
  (uint16)Ccu6_SetPtns(5, 1, 0x07), /* Hall pattern=5, reverse direction */
  (uint16)Ccu6_SetPtns(6, 4, 0x31), /* Hall pattern=6, reverse direction */
  (uint16)Ccu6_SetPtns(0, 0, 0x00)  /* Hall pattern=7, reverse direction (error) */
 },
#else     /* Nanotec DB42S03 motor */
{
  (uint16)Ccu6_SetPtns(0, 0, 0x00), /* Hall pattern=0, forward direction (error) */
  (uint16)Ccu6_SetPtns(1, 5, 0x31), /* Hall pattern=1, forward direction */
  (uint16)Ccu6_SetPtns(2, 3, 0x07), /* Hall pattern=2, forward direction */
  (uint16)Ccu6_SetPtns(3, 1, 0x34), /* Hall pattern=3, forward direction */
  (uint16)Ccu6_SetPtns(4, 6, 0x1C), /* Hall pattern=4, forward direction */
  (uint16)Ccu6_SetPtns(5, 4, 0x0D), /* Hall pattern=5, forward direction */
  (uint16)Ccu6_SetPtns(6, 2, 0x13), /* Hall pattern=6, forward direction */
  (uint16)Ccu6_SetPtns(0, 0, 0x00), /* Hall pattern=7, forward direction (error) */
  (uint16)Ccu6_SetPtns(0, 0, 0x00), /* Hall pattern=0, reverse direction (error) */
  (uint16)Ccu6_SetPtns(1, 3, 0x13), /* Hall pattern=1, reverse direction */
  (uint16)Ccu6_SetPtns(2, 6, 0x0D), /* Hall pattern=2, reverse direction */
  (uint16)Ccu6_SetPtns(3, 2, 0x1C), /* Hall pattern=3, reverse direction */
  (uint16)Ccu6_SetPtns(4, 5, 0x34), /* Hall pattern=4, reverse direction */
  (uint16)Ccu6_SetPtns(5, 1, 0x07), /* Hall pattern=5, reverse direction */
  (uint16)Ccu6_SetPtns(6, 4, 0x31), /* Hall pattern=6, reverse direction */
  (uint16)Ccu6_SetPtns(0, 0, 0x00)  /* Hall pattern=7, reverse direction (error) */
  },
#endif


  /* T12Moden - T12 modulation enable patterns
   * Table value = 0x80(MCMEN) + pattern for T12MODEN
   * Pattern = COUT62*32 + CC62*16 + COUT61*8 + CC61*4 + COUT60*2 + CC60 */
#if MOTOR_TYPE == 0 /* QBL4208-41-03-006 motor */
{
  (uint8)(0x00),        /* Hall pattern=0, forward direction (error) */
  (uint8)(0x80 + 0x0F), /* Hall pattern=1, forward direction */
  (uint8)(0x80 + 0x3C), /* Hall pattern=2, forward direction */
  (uint8)(0x80 + 0x0C), /* Hall pattern=3, forward direction */
  (uint8)(0x80 + 0x33), /* Hall pattern=4, forward direction */
  (uint8)(0x80 + 0x03), /* Hall pattern=5, forward direction */
  (uint8)(0x80 + 0x30), /* Hall pattern=6, forward direction */
  (uint8)(0x00),        /* Hall pattern=7, forward direction (error) */
  (uint8)(0x00),        /* Hall pattern=0, reverse direction (error) */
  (uint8)(0x80 + 0x30), /* Hall pattern=1, reverse direction */
  (uint8)(0x80 + 0x03), /* Hall pattern=2, reverse direction */
  (uint8)(0x80 + 0x33), /* Hall pattern=3, reverse direction */
  (uint8)(0x80 + 0x0C), /* Hall pattern=4, reverse direction */
  (uint8)(0x80 + 0x3C), /* Hall pattern=5, reverse direction */
  (uint8)(0x80 + 0x0F), /* Hall pattern=6, reverse direction */
  (uint8)(0x00)         /* Hall pattern=7, reverse direction (error) */
},
#elif MOTOR_TYPE == 1  /* QBL4208-61-04-013 motor */
{
  (uint8)(0x00),        /* Hall pattern=0, forward direction (error) */
  (uint8)(0x80 + 0x3C), /* Hall pattern=1, forward direction */
  (uint8)(0x80 + 0x33), /* Hall pattern=2, forward direction */
  (uint8)(0x80 + 0x30), /* Hall pattern=3, forward direction */
  (uint8)(0x80 + 0x0F), /* Hall pattern=4, forward direction */
  (uint8)(0x80 + 0x0C), /* Hall pattern=5, forward direction */
  (uint8)(0x80 + 0x03), /* Hall pattern=6, forward direction */
  (uint8)(0x00),        /* Hall pattern=7, forward direction (error) */
  (uint8)(0x00),        /* Hall pattern=0, reverse direction (error) */
  (uint8)(0x80 + 0x03), /* Hall pattern=1, reverse direction */
  (uint8)(0x80 + 0x0C), /* Hall pattern=2, reverse direction */
  (uint8)(0x80 + 0x0F), /* Hall pattern=3, reverse direction */
  (uint8)(0x80 + 0x30), /* Hall pattern=4, reverse direction */
  (uint8)(0x80 + 0x33), /* Hall pattern=5, reverse direction */
  (uint8)(0x80 + 0x3C), /* Hall pattern=6, reverse direction */
  (uint8)(0x00)         /* Hall pattern=7, reverse direction (error) */
},
#else  /* Nanotec DB42S03 motor */
{
  (uint8)(0x00),        /* Hall pattern=0, forward direction (error) */
  (uint8)(0x80 + 0x3C), /* Hall pattern=1, forward direction */
  (uint8)(0x80 + 0x33), /* Hall pattern=2, forward direction */
  (uint8)(0x80 + 0x30), /* Hall pattern=3, forward direction */
  (uint8)(0x80 + 0x0F), /* Hall pattern=4, forward direction */
  (uint8)(0x80 + 0x0C), /* Hall pattern=5, forward direction */
  (uint8)(0x80 + 0x03), /* Hall pattern=6, forward direction */
  (uint8)(0x00),        /* Hall pattern=7, forward direction (error) */
  (uint8)(0x00),        /* Hall pattern=0, reverse direction (error) */
  (uint8)(0x80 + 0x03), /* Hall pattern=1, reverse direction */
  (uint8)(0x80 + 0x0C), /* Hall pattern=2, reverse direction */
  (uint8)(0x80 + 0x0F), /* Hall pattern=3, reverse direction */
  (uint8)(0x80 + 0x30), /* Hall pattern=4, reverse direction */
  (uint8)(0x80 + 0x33), /* Hall pattern=5, reverse direction */
  (uint8)(0x80 + 0x3C), /* Hall pattern=6, reverse direction */
  (uint8)(0x00)         /* Hall pattern=7, reverse direction (error) */
},
#endif
}; /* End of EmoCcu_Cfg */

