/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * The applicable license agreement can be found at this pack's installation directory in the file
 * license/IFX_SW_Licence_MOTIX_LITIX.txt
 *
 **********************************************************************************************************************/
 
/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** MK           Martin Kilian                                                 **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2021-05-14, MK:   Initial version of the example (C code)          **
** V1.0.1: 2021-10-07, MK:   EP-974: Removed double step in aligmnent,        **
**                           Moved Hall_Handling to #ifdef in WHE ISR         **
** V1.0.2: 2025-01-02, JO:   EP-1493: Updated license                         **
*******************************************************************************/

#ifndef BLDC_MOTOR_LIB_H
#define BLDC_MOTOR_LIB_H

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/
#include "tle_device.h"
#include "bldc_defines.h"

/*******************************************************************************
**                          Global Macro Declarations                         **
*******************************************************************************/
/* Motor States */
#define MOTOR_STATE_STARTUP 0
#define MOTOR_STATE_RUNNING 20
#define MOTOR_STATE_STOP    30

/* Defines for Motor_Direction_Set() */
#define ACTIVE_PATTERN_MAX  6u /* 0...5  */
#define DIR_FORWARD         1u /* (index + 1u) % 6 => 0 1 2 3 4 5 0... */
#define DIR_BACKWARD        5u /* (index + 5u) % 6 => 0 5 4 3 2 1 0... */

/*******************************************************************************
**                          Global Type Declarations                          **
*******************************************************************************/
/* Motor Variable Structure */
struct _Motor
{
  uint32 active_pattern;  /* current Motor pattern */
  uint32 dutycycle;       /* PWM dutycycle, raw value of CCU6 */
  uint32 dir;             /* Motor Direction */
  uint32 value_60_degree; /* Time for 60 of an electrical round, 1/FSYS ticks */
  uint32 state;           /* Motor States: defined above */
};

/* Startup Variable Structure */
struct _Startup_Config
{
  uint32 dutycycle  ; /* dutycylce during startup */
  uint32 speed_end  ; /* ticks at end of startup, initialised with rpm2ticks */
  uint32 speed_count; /* counter variable during startup */
  uint32 ramp       ; /* startup ramp scaled by bitshift --> makes no sense at the moment */
};

/* Hall Variable Structure */
struct _Hall
{
  uint32 value_60_degree;
  uint32 speed;
  uint32 delay;
  uint8  patterns[6];
};

/*******************************************************************************
**                         Motor Variables                                    **
*******************************************************************************/
extern volatile struct _Startup_Config Startup_Config;
extern volatile struct _Motor Motor;
extern volatile struct _Hall  Hall;


/*******************************************************************************
**                         Global Function Declarations                       **
*******************************************************************************/
void   Motor_Init(uint32 Motor_Direction); 
void   Motor_Startup(void);
void   Motor_Stop(void);
void   Motor_Step_Speed_Set(uint32 rpm);
void   Motor_Dutycycle_Set(uint32 Dutycycle);
uint32 Motor_Dutycycle_Get(void);
void   Motor_VoltageDC_Set(uint32 voltage);
uint32 Motor_State_Get(void);
void   Motor_State_Set(uint32 state);
uint32 Motor_Speed_Get(void);
void   Motor_Direction_Set(uint32 direction);
void   Motor_Step(void);

uint32 Rpm2Ticks(uint32 rpm);
uint32 Ticks2Rpm(uint32 ticks);


#endif
