/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * The applicable license agreement can be found at this pack's installation directory in the file
 * license/IFX_SW_Licence_MOTIX_LITIX.txt
 *
 **********************************************************************************************************************/
 
 /******************************* Speedcontroller **********************************************\
 *                                   ________                                                  *
 *                                  |        |                                                 *
 *                             /--->| P_Gain |----\                                            *
 *                             |    |________|    |                                            *
 *  SC_Refspeed_Set(refspeed); |     ________     |     ______________  int Speed_Control()    *
 *       ->sc.refspeed         |    |        |  + |+   |              | -> sc.out              *
 *           -------->O--->--->O--->| I_Gain |--->O--->| SC_SCALE_OUT |-------------------->   *
 *                    |-       |    |________|   +|    |______________|                        *
 *                    |        |     ________     |                                            *
 *                    |        |    |        |    |                                            *
 *                    |        \--->| D_Gain |----/                                            *
 *                    |             |________|                SC_Actspeed_Set(int actspeed);   *
 *                    |                                       -> sc.actspeed                   *
 *                    \----<--------<----------<-----------<----------<----------<------       *
 *                                                                                             *
 **********************************************************************************************/

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/
#include "speedcontrol.h"

/*******************************************************************************
**                         Global Variable Definitions                        **
*******************************************************************************/
struct _speedcontrol sc;

/*******************************************************************************
**                        Global Function Definitions                         **
*******************************************************************************/
void Speed_Control_Init(void)
{
  sc.refspeed       = 0;
  sc.actspeed       = 0;
  sc.P_gain         = SC_P_GAIN;
  sc.P_value        = 0;
  sc.I_gain         = SC_I_GAIN;
  sc.I_value        = 0;
  sc.D_gain         = SC_D_GAIN;
  sc.D_value        = 0;
  sc.error          = 0;
  sc.error_Integral = 0;
  sc.error_diff     = 0;
  sc.out            = DUTYCYCLE_MIN;
}

int Speed_Control(void)
{
  int out;                                                                   /* help variable */
  sc.error           =  sc.refspeed - sc.actspeed;                           /* error calculation */
  sc.P_value         = (sc.error * sc.P_gain)/SC_SCALE_P;                    /* P_gain scaled 1 to 1000 */
  sc.error_Integral +=  sc.error ;                                           /* error Integral */
  if(sc.error_Integral >  SC_INTEGRAL_LIMIT){sc.error_Integral =  SC_INTEGRAL_LIMIT;}
  if(sc.error_Integral < -SC_INTEGRAL_LIMIT){sc.error_Integral = -SC_INTEGRAL_LIMIT;}
  sc.I_value         = (sc.error_Integral * sc.I_gain)/SC_SCALE_I;           /* I_gain scaled 1 to 1000 */
  sc.D_value         = ((sc.error_diff - sc.error)*sc.D_gain) / SC_SCALE_D;  /* D_gain scaled 1 to 1000 */
  sc.error_diff      =  sc.error;                                            /* old error is new error */
  out                =  sc.out + sc.P_value + sc.I_value + sc.D_value;       /* Speedcontrol output */
  
  out = out/SC_SCALE_OUT; /* Output scale to max_dutycycle */
  
  /* Limiter for Max and Min Dutycycle */
  if(out > DUTYCYCLE_MAX) { out = DUTYCYCLE_MAX;}
  if(out < DUTYCYCLE_MIN) { out = DUTYCYCLE_MIN;}
  
  sc.out = out;
  //sc.out = (3*sc.out+out)/4; // Set output variable /1 to 4 filter
  
  return out;
}

void SC_Refspeed_Set(int refspeed)
{
  sc.refspeed = (sc.refspeed+refspeed)/2;
}
void SC_Actspeed_Set(int actspeed)
{
  sc.actspeed = (sc.actspeed+actspeed)/2;
}
