/*
 ***********************************************************************************************************************
 *
 * Copyright (c) 2021, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/
 
/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** MK           Martin Kilian                                                 **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2021-05-14, MK:   Initial version of the example (C code)          **
*******************************************************************************/

/******************************* Speedcontroller ***********************************************
 *                                   ________                                                  *
 *                                  |        |                                                 *
 *                             /--->| P_Gain |----\                                            *
 *                             |    |________|    |                                            *
 *  SC_Refspeed_Set(refspeed); |     ________     |     ______________  int Speed_Control();   *
 *  ->sc.refspeed      sc.error|    |        |  + |+   |              | -> sc.out              *
 *       ------------>O------->O--->| I_Gain |--->O--->| SC_SCALE_OUT |-------------------->   *
 *                    |-       |    |________|   +|    |______________|                        *
 *                    |        |     ________     |                                            *
 *                    |        |    |        |    |                                            *
 *                    |        \--->| D_Gain |----/                                            *
 *                    |             |________|                SC_Actspeed_Set(int actspeed);   *                            *
 *                    |                                       -> sc.actspeed                   *
 *                    \----<--------<----------<-----------<----------<----------<------       *
 *                                                                                             *
 ***********************************************************************************************/
 
#ifndef SPEEDCONTROL_LIB_H
#define SPEEDCONTROL_LIB_H

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/
#include "speedctrl_defines.h"

/*******************************************************************************
**                          Global Type Declarations                          **
*******************************************************************************/
struct _speedcontrol
{
  int refspeed; 
  int actspeed;
  int P_gain ;
  int P_value;
  int I_gain ;
  int I_value;
  int D_gain ;
  int D_value;
  int error;
  int error_Integral;
  int error_diff;
  int out; 
};

/*******************************************************************************
**                         Global Variable Definitions                        **
*******************************************************************************/
extern struct _speedcontrol sc;

/*******************************************************************************
**                         Global Function Declarations                       **
*******************************************************************************/
void Speed_Control_Init(void);
int  Speed_Control(void);
void SC_Refspeed_Set(int refspeed);
void SC_Actspeed_Set(int actspeed);

#endif
