/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * The applicable license agreement can be found at this pack's installation directory in the file
 * license/IFX_SW_Licence_MOTIX_LITIX.txt
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2020-04-15, BG:   Initial version of revision history              **
** V1.0.1: 2020-07-21, BG:   EP-439: Formatted .h/.c files                    **
** V1.0.2: 2020-08-04, BG:   EP-431: Fixed ARMCC v6 compiler warnings         **
** V1.1.0: 2024-11-06, JO:   EP-1535: Fixed compiler warnings (ARMCC V6.22)   **
** V1.1.1: 2025-01-02, JO:   EP-1493: Updated license                         **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** CCU6 SIN PWM: Generation of three different PWMs (50us), 120, sinusoidal  **
********************************************************************************
** Timer12 is running at a 50us period in center-aligned mode.                **
** The three compare channel have a compare match at:                         **
** Channel | DC  | CC6x | COUT6x                                              **
** -----------------------------                                              **
**   Ch0   | sin | P0.4 | P0.2                                                **
**   Ch1   | sin | P1.0 | P1.1                                                **
**   Ch2   | sin | P1.3 | P1.4                                                **
*******************************************************************************/

#include "tle_device.h"
#include "sinus.h"
#include "eval_board.h"

void Task_1ms(void);

static uint16 deg = 0;
static uint32 pc0, pc1;


int main(void)
{
  /* Initialization of hardware modules based on Config Wizard configuration */
  TLE_Init();
  CCU6_StartTmr_T12();

  for (;;)
  {
    (void)WDT1_Service();
  }
}


/* math.h : 379us runtime @ 40MHz */
/* sinus.h:  37us runtime @ 40MHz */
void Task_1ms(void)
{
  #define PI 3.14159265
  static double res;
  
  uint16 deg1, deg2;
  uint16 cmp0;
  uint16 cmp1;
  uint16 cmp2;
  pc0 = CPU->SYSTICK_CUR.reg;
  deg++;

  if (deg > 359)
  {
    deg = 0;
  }

  //res = sin(deg*PI/180);
  res = sinus[deg];
  cmp0 = (uint16) ((CCU6_T12PR / 2) * res + (CCU6_T12PR / 2));
  deg1 = deg + 120;

  if (deg1 > 359)
  {
    deg1 -= 360;
  }

  //res = sin(deg1*PI/180);
  res = sinus[deg1];
  cmp1 = (uint16) ((CCU6_T12PR / 2) * res + (CCU6_T12PR / 2));
  deg2 = deg + 240;

  if (deg2 > 359)
  {
    deg2 -= 360;
  }

  //res = sin(deg2*PI/180);
  res = sinus[deg2];
  cmp2 = (uint16) ((CCU6_T12PR / 2) * res + (CCU6_T12PR / 2));
  CCU6_LoadShadowRegister_CC60(cmp0);
  CCU6_LoadShadowRegister_CC61(cmp1);
  CCU6_LoadShadowRegister_CC62(cmp2);
  CCU6_EnableST_T12();
  pc1 = CPU->SYSTICK_CUR.reg;
}
