/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * The applicable license agreement can be found at this pack's installation directory in the file
 * license/IFX_SW_Licence_MOTIX_LITIX.txt
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2020-04-15, BG:   Initial version of revision history              **
** V1.0.1: 2020-07-21, BG:   EP-439: Formatted .h/.c files                    **
** V1.0.2: 2020-08-04, BG:   EP-431: Fixed ARMCC v6 compiler warnings         **
** V1.1.0: 2024-11-06, JO:   EP-1535: Fixed compiler warnings (ARMCC V6.22)   **
** V1.1.1: 2025-01-02, JO:   EP-1493: Updated license                         **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** GPT12E: Concatenation of T2 and T3                                         **
********************************************************************************
** Both core timer T3 and auxiliary timer T2 of GPT12E are concatenated       **
** resulting in a 32bit timer.                                                **
** P0.2 toggles every: max. timer value * GPT clock[s]                        **
** With TLE9879QXA40: max. timer value: 4294967295 (0xFFFFFFFF)               **
**                    GPT clock set up in ConfigWizard: 10MHz -> T_GPT = 100ns**
**                    => P0.2 toggles every 429 seconds ~ 7 min 9 s           **
*******************************************************************************/

#include "tle_device.h"
#include "eval_board.h"

void Seven_Minutes_Task(void);


int main(void)
{
  /* Initialization of hardware modules based on Config Wizard configuration */
  TLE_Init();
  /* Start core timer T3 of GPT12E */
  GPT12E_T3_Start();

  for (;;)
  {
    (void)WDT1_Service();
  }
}


void Seven_Minutes_Task(void)
{
  /* Toggle LED2 (P0.2) on concatenated timer overflow */
  PORT_ChangePin(LED2, PORT_ACTION_TOGGLE);
}
