/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * The applicable license agreement can be found at this pack's installation directory in the file
 * license/IFX_SW_Licence_MOTIX_LITIX.txt
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2020-04-15, BG:   Initial version of revision history              **
** V1.0.1: 2020-07-21, BG:   EP-439: Formatted .h/.c files                    **
** V1.0.2: 2025-01-02, JO:   EP-1493: Updated license                         **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** PMU: Power saving - Stop mode                                              **
********************************************************************************
** Send the device into StopMode by pulling P1.0 to high.                     **
** The device wakes up by MON (configured by default) and Reset.              **
** Observe a VDDC reduction of ~0.9V.                                         **
*******************************************************************************/

#include "tle_device.h"
#include "eval_board.h"

int main(void)
{
  /* Initialization of hardware modules based on Config Wizard configuration */
  TLE_Init();
  /* Turn on LED1 (P0.1) */
  PORT_ChangePin(LED1, PORT_ACTION_SET);

  for (;;)
  {
    (void)WDT1_Service();

    /* If P1.0 is set high, ... */
    if (PORT_ReadPin(0x10) == 1)
    {
      /* ..., the device enters stop mode */
      SCU_EnterStopMode();
      /* LED2 (P0.2) is turned on */
      PORT_ChangePin(LED2, PORT_ACTION_SET);
    }
  }
}
