/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * The applicable license agreement can be found at this pack's installation directory in the file
 * license/IFX_SW_Licence_MOTIX_LITIX.txt
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2020-04-15, BG:   Initial version of revision history              **
** V1.0.1: 2020-07-21, BG:   EP-439: Formatted .h/.c files                    **
** V1.0.2: 2020-08-04, BG:   EP-431: Fixed ARMCC v6 compiler warnings         **
** V1.1.0: 2024-11-06, JO:   EP-1535: Fixed compiler warnings (ARMCC V6.22)   **
** V1.1.1: 2025-01-02, JO:   EP-1493: Updated license                         **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** SSC1/SSC2: Send data from SSC1 to SSC2                                     **
********************************************************************************
** Both SSC operate at 1Mbaud. SSC1 sends one byte at P0.3 (CLK), P0.2 (MTSR).**
** SSC2 receives one byte at P1.0 (CLK), P1.1 (MTSR). Connect clock signals   **
** and data signal from SSC1 and SSC2 together.                               **
** LED7 is set on receive.                                                    **
*******************************************************************************/

#include "tle_device.h"
#include "eval_board.h"

void Data_Received(void);


int main(void)
{
  /* Initialization of hardware modules based on Config Wizard configuration */
  TLE_Init();
  SSC1_SendWord((uint16) 0xAAAA);

  for (;;)
  {
    (void)WDT1_Service();
  }
}


void Data_Received(void)
{
  uint16 data = SSC2_ReadWord();

  if (data == (uint16) 0x00AA)
  {
    PORT_ChangePin(LED7, PORT_ACTION_SET);
  }
}
