/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * The applicable license agreement can be found at this pack's installation directory in the file
 * license/IFX_SW_Licence_MOTIX_LITIX.txt
 *
 **********************************************************************************************************************/
/**
 * \file     system_tle987x.h
 *
 * \brief    System file for TLE987x
 *
 * \version  V0.5.1
 * \date     02. Jan 2025
 */

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** DM           Daniel Mysliwitz                                              **
** JO           Julia Ott                                                     **
** BG           Blandine Guillot                                              **
** VO           Vanessa Ongaro                                                **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V0.0.2: 2017-11-10, DM:   Latest system_tle987x.h version                  **
** V0.4.0: 2017-11-10, DM:   Latest system_tle987x.c version                  **
** V0.4.1: 2018-12-05, DM:   system_tle987x.h, system_tle987x.c revisions     **
**                           merged                                           **
** V0.4.2: 2019-02-04, DM:   NAC/NAD pointer modified to be ARMCC v6 compliant**
** V0.4.3: 2019-09-13, JO:   Corrected filename in Revision Control History   **
** V0.4.4: 2020-04-15, BG:   Updated revision history format                  **
** V0.4.5: 2020-07-14, JO:   Added #include "system_tle987x.h" to             **
**                           system_tle987x.c                                 **
** V0.4.6: 2020-07-21, BG:   EP-439: Formatted .h/.c files                    **
** V0.4.7: 2021-05-28, BG:   EP-175: Added compatibility with IAR compiler    **
** V0.4.8: 2021-06-15, JO:   EP-840: Fixed NACNAD placement when using ARMCC  **
**                           v6 and LTO by adding attribute used              **
**                           Added #error Unsupported compiler! in case no    **
**                           supported compiler define is found               **
** V0.4.9: 2022-02-28, JO:   EP-936: Updated copyright and branding           **
** V0.5.0: 2022-11-04, VO:   EP-1323: Corrected NAC/NAD placement with IAR    **
** V0.5.1: 2025-01-02, JO:   EP-1493: Updated license                         **
*******************************************************************************/

#ifndef __SYSTEM_TLE987x_H
#define __SYSTEM_TLE987x_H

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/
#include "types.h"

#ifdef __cplusplus
extern "C" {
#endif

extern uint32 SystemFrequency;
extern const uint32 p_NACNAD;

/** \brief Initialize System, clock and watchdog1.
 */
void SystemInit (void);

#ifdef __cplusplus
}
#endif

#endif /* __SYSTEM_TLE987x_H */
